package Alien::Librdkafka;
 
use strict;
use warnings;
 
use parent 'Alien::Base';
our $VERSION = '0.9.5';

=head1 NAME

Alien::Librdkafka - build and install librdkafka

=head1 DESCRIPTION

The distribution provides the way to build and access librdkafka from perl.

=head1 SEE ALSO

L<Alien::Base>

L<https://github.com/edenhill/librdkafka>

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2016, 2017 Pavel Shaydo

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

For librdkafka license and copyright check L<https://github.com/edenhill/librdkafka>

=cut
 
1;
